@@ -1,6 +1,8 @@
 # ABSTRACT: Creates db_util command line for DB_File management
 package DB_File::Utils;
-$DB_File::Utils::VERSION = '0.004';
+$DB_File::Utils::VERSION = '0.005';
+use warnings;
+use strict;
 use DB_File;
 use Fcntl;
 
@@ -57,3 +59,12 @@ db_util (3)
 =head1 AUTHOR
 
 Alberto Simões C<< <ambs@cpan.org> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Alberto Simões.
+
+This is free software; you can redistribute it and/or modify
+it under the same terms as the Perl 5 programming language system itself.
+
+=cut
\ No newline at end of file
